@@ -42,7 +42,7 @@ class Wrapper:
             self.current_command = attr
             return self._execute
         else:
-            raise AttributeError(attr)
+            raise AttributeError('No executable with name {} found in path {}'.format(attr, str(self.path_to_exe)))
 
     def _execute(self, *args):
         """
@@ -228,7 +228,7 @@ class CacheWorkspace:
 
 
 def save_to_project(save_fn: callable, file_path: str, *args, file_path_arg_pos: int = 0,
-                    cache_workspace: CacheWorkspace = None, path_to_datamover: str = '/sw/taurus/tools/slurmtools/default/bin/', path_to_workspace_tools: str = '/usr/bin/', **kw):
+                    cache_workspace: CacheWorkspace = None, path_to_datamover: str = '/sw/taurus/tools/slurmtools/default/bin/', path_to_workspace_tools: str = '/usr/bin/', quiet=False, **kw):
     '''Save data to a project space.
 
     Since we don't have direct access, we first save to a temporary file on a workspace and then copy to the project space.
@@ -269,7 +269,7 @@ def save_to_project(save_fn: callable, file_path: str, *args, file_path_arg_pos:
         args = args[0:file_path_arg_pos] + \
             (str(temp_file),) + args[file_path_arg_pos:]
         output = save_fn(*args, **kw)
-        waitfor(dm.dtcp(str(temp_file), str(full_path)))
+        waitfor(dm.dtcp(str(temp_file), str(full_path)), quiet=quiet)
         print('target file: {}'.format(str(full_path)))
     if cleanup:
         cache_workspace.cleanup()
@@ -277,7 +277,7 @@ def save_to_project(save_fn: callable, file_path: str, *args, file_path_arg_pos:
 
 
 def waitfor(process: subprocess.Popen, timeout_in_s: float = -1,
-            discard_output: bool = True) -> int:
+            discard_output: bool = True, quiet: bool = True) -> int:
     """
     Wait for a process to complete.
 
@@ -293,10 +293,12 @@ def waitfor(process: subprocess.Popen, timeout_in_s: float = -1,
     int exit code of the process
     """
     start_time = time.time()
-    print("Waiting .", end='', flush=True)
+    if not quiet:
+        print("Waiting .", end='', flush=True)
     while process.poll() is None:
         time.sleep(0.5)
-        print(".", end='', flush=True)
+        if not quiet:
+            print(".", end='', flush=True)
         if timeout_in_s > 0 and (time.time() - start_time) > timeout_in_s:
             print("\n")
             warnings.warn(
